==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/FieldDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Definition of the connection fields.
 * @property isEncrypted Gets or sets the isEncrypted flag of the connection field definition.
 * @property isOptional Gets or sets the isOptional flag of the connection field definition.
 * @property type Gets or sets the type of the connection field definition.
 */
public data class FieldDefinitionArgs(
    public val isEncrypted: Output<Boolean>? = null,
    public val isOptional: Output<Boolean>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs =
        com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs.builder()
            .isEncrypted(isEncrypted?.applyValue({ args0 -> args0 }))
            .isOptional(isOptional?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FieldDefinitionArgs].
 */
@PulumiTagMarker
public class FieldDefinitionArgsBuilder internal constructor() {
    private var isEncrypted: Output<Boolean>? = null

    private var isOptional: Output<Boolean>? = null

    private var type: Output<String>? = null

    /**
     * @param value Gets or sets the isEncrypted flag of the connection field definition.
     */
    @JvmName("vulyxtjrtqeyemqt")
    public suspend fun isEncrypted(`value`: Output<Boolean>) {
        this.isEncrypted = value
    }

    /**
     * @param value Gets or sets the isOptional flag of the connection field definition.
     */
    @JvmName("leghatmwspacyqkq")
    public suspend fun isOptional(`value`: Output<Boolean>) {
        this.isOptional = value
    }

    /**
     * @param value Gets or sets the type of the connection field definition.
     */
    @JvmName("ckytxapegsokssue")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the isEncrypted flag of the connection field definition.
     */
    @JvmName("syketrxhxrnapakk")
    public suspend fun isEncrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEncrypted = mapped
    }

    /**
     * @param value Gets or sets the isOptional flag of the connection field definition.
     */
    @JvmName("fvgpbdpsdeiegtku")
    public suspend fun isOptional(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isOptional = mapped
    }

    /**
     * @param value Gets or sets the type of the connection field definition.
     */
    @JvmName("fassyrcpcubblpmv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): FieldDefinitionArgs = FieldDefinitionArgs(
        isEncrypted = isEncrypted,
        isOptional = isOptional,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/FieldDefinitionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Definition of the connection fields.
 * @property isEncrypted Gets or sets the isEncrypted flag of the connection field definition.
 * @property isOptional Gets or sets the isOptional flag of the connection field definition.
 * @property type Gets or sets the type of the connection field definition.
 */
public data class FieldDefinitionArgs(
    public val isEncrypted: Output<Boolean>? = null,
    public val isOptional: Output<Boolean>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs =
        com.pulumi.azurenative.automation.inputs.FieldDefinitionArgs.builder()
            .isEncrypted(isEncrypted?.applyValue({ args0 -> args0 }))
            .isOptional(isOptional?.applyValue({ args0 -> args0 }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [FieldDefinitionArgs].
 */
@PulumiTagMarker
public class FieldDefinitionArgsBuilder internal constructor() {
    private var isEncrypted: Output<Boolean>? = null

    private var isOptional: Output<Boolean>? = null

    private var type: Output<String>? = null

    /**
     * @param value Gets or sets the isEncrypted flag of the connection field definition.
     */
    @JvmName("batjmlahlxjkobdl")
    public suspend fun isEncrypted(`value`: Output<Boolean>) {
        this.isEncrypted = value
    }

    /**
     * @param value Gets or sets the isOptional flag of the connection field definition.
     */
    @JvmName("favqvgcmmkitsykk")
    public suspend fun isOptional(`value`: Output<Boolean>) {
        this.isOptional = value
    }

    /**
     * @param value Gets or sets the type of the connection field definition.
     */
    @JvmName("xxfonhspjfxkyvqc")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the isEncrypted flag of the connection field definition.
     */
    @JvmName("svmqisiwqhfjmaec")
    public suspend fun isEncrypted(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isEncrypted = mapped
    }

    /**
     * @param value Gets or sets the isOptional flag of the connection field definition.
     */
    @JvmName("mofdkooxqalhwgfq")
    public suspend fun isOptional(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isOptional = mapped
    }

    /**
     * @param value Gets or sets the type of the connection field definition.
     */
    @JvmName("skmnjjvclybaglvn")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): FieldDefinitionArgs = FieldDefinitionArgs(
        isEncrypted = isEncrypted,
        isOptional = isOptional,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
